from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="EventCount")


@_attrs_define
class EventCount:
    """
    Attributes:
        count_acceleration (Union[Unset, int]):
        count_ball_contact (Union[Unset, int]):
        count_ball_possession (Union[Unset, int]):
        count_ball_possession_lost (Union[Unset, int]):
        count_ball_possession_recovery (Union[Unset, int]):
        count_cv_shot (Union[Unset, int]):
        count_change_of_direction (Union[Unset, int]):
        count_change_of_orientation (Union[Unset, int]):
        count_change_of_pace (Union[Unset, int]):
        count_corner_kick (Union[Unset, int]):
        count_counter_attack (Union[Unset, int]):
        count_detected_cross (Union[Unset, int]):
        count_cut (Union[Unset, int]):
        count_deceleration (Union[Unset, int]):
        count_defence (Union[Unset, int]):
        count_detected_offside_soccer (Union[Unset, int]):
        count_detected_pass (Union[Unset, int]):
        count_detected_shot_basketball (Union[Unset, int]):
        count_detected_shot_fifa (Union[Unset, int]):
        count_detected_shot_handball (Union[Unset, int]):
        count_detected_shot_ice_hockey (Union[Unset, int]):
        count_detected_shot_intelligence_court (Union[Unset, int]):
        count_detected_shot_soccer (Union[Unset, int]):
        count_dfl_corner_kick (Union[Unset, int]):
        count_dfl_cross (Union[Unset, int]):
        count_dfl_free_kick (Union[Unset, int]):
        count_dfl_goal_kick (Union[Unset, int]):
        count_dfl_kick_off (Union[Unset, int]):
        count_dfl_pass (Union[Unset, int]):
        count_dfl_penalty (Union[Unset, int]):
        count_dfl_shot_at_goal (Union[Unset, int]):
        count_dfl_sprint (Union[Unset, int]):
        count_dfl_tackling (Union[Unset, int]):
        count_dfl_throw_in (Union[Unset, int]):
        count_down_on_pads (Union[Unset, int]):
        count_dribbling_soccer (Union[Unset, int]):
        count_dynamic_defence (Union[Unset, int]):
        count_exertion (Union[Unset, int]):
        count_full_court_transition (Union[Unset, int]):
        count_goal_kick (Union[Unset, int]):
        count_goalkeeper_save_diving (Union[Unset, int]):
        count_goalkeeper_save_down_to_knees (Union[Unset, int]):
        count_goalkeeper_save_tilting (Union[Unset, int]):
        count_group_counter_pressing (Union[Unset, int]):
        count_group_empty_goal_handball (Union[Unset, int]):
        count_heart_rate_recovery (Union[Unset, int]):
        count_impact (Union[Unset, int]):
        count_jump_beach_volleyball (Union[Unset, int]):
        count_jump (Union[Unset, int]):
        count_mid_court_transition (Union[Unset, int]):
        count_noah_shot (Union[Unset, int]):
        count_offence (Union[Unset, int]):
        count_pass_fifa (Union[Unset, int]):
        count_pick_and_pop (Union[Unset, int]):
        count_pick_and_roll (Union[Unset, int]):
        count_pivot_rotation (Union[Unset, int]):
        count_play_by_player (Union[Unset, int]):
        count_play_by_team (Union[Unset, int]):
        count_player_counter_pressing (Union[Unset, int]):
        count_rally_beach_volleyball (Union[Unset, int]):
        count_rspct_shot (Union[Unset, int]):
        count_shift (Union[Unset, int]):
        count_skating_transition (Union[Unset, int]):
        count_speed_zone_entry (Union[Unset, int]):
        count_speed_zone_entry_relative (Union[Unset, int]):
        count_sprint (Union[Unset, int]):
        count_tag (Union[Unset, int]):
        count_tempo_run (Union[Unset, int]):
        count_throw_in (Union[Unset, int]):
        count_turn_ice_hockey (Union[Unset, int]):
    """

    count_acceleration: Union[Unset, int] = UNSET
    count_ball_contact: Union[Unset, int] = UNSET
    count_ball_possession: Union[Unset, int] = UNSET
    count_ball_possession_lost: Union[Unset, int] = UNSET
    count_ball_possession_recovery: Union[Unset, int] = UNSET
    count_cv_shot: Union[Unset, int] = UNSET
    count_change_of_direction: Union[Unset, int] = UNSET
    count_change_of_orientation: Union[Unset, int] = UNSET
    count_change_of_pace: Union[Unset, int] = UNSET
    count_corner_kick: Union[Unset, int] = UNSET
    count_counter_attack: Union[Unset, int] = UNSET
    count_detected_cross: Union[Unset, int] = UNSET
    count_cut: Union[Unset, int] = UNSET
    count_deceleration: Union[Unset, int] = UNSET
    count_defence: Union[Unset, int] = UNSET
    count_detected_offside_soccer: Union[Unset, int] = UNSET
    count_detected_pass: Union[Unset, int] = UNSET
    count_detected_shot_basketball: Union[Unset, int] = UNSET
    count_detected_shot_fifa: Union[Unset, int] = UNSET
    count_detected_shot_handball: Union[Unset, int] = UNSET
    count_detected_shot_ice_hockey: Union[Unset, int] = UNSET
    count_detected_shot_intelligence_court: Union[Unset, int] = UNSET
    count_detected_shot_soccer: Union[Unset, int] = UNSET
    count_dfl_corner_kick: Union[Unset, int] = UNSET
    count_dfl_cross: Union[Unset, int] = UNSET
    count_dfl_free_kick: Union[Unset, int] = UNSET
    count_dfl_goal_kick: Union[Unset, int] = UNSET
    count_dfl_kick_off: Union[Unset, int] = UNSET
    count_dfl_pass: Union[Unset, int] = UNSET
    count_dfl_penalty: Union[Unset, int] = UNSET
    count_dfl_shot_at_goal: Union[Unset, int] = UNSET
    count_dfl_sprint: Union[Unset, int] = UNSET
    count_dfl_tackling: Union[Unset, int] = UNSET
    count_dfl_throw_in: Union[Unset, int] = UNSET
    count_down_on_pads: Union[Unset, int] = UNSET
    count_dribbling_soccer: Union[Unset, int] = UNSET
    count_dynamic_defence: Union[Unset, int] = UNSET
    count_exertion: Union[Unset, int] = UNSET
    count_full_court_transition: Union[Unset, int] = UNSET
    count_goal_kick: Union[Unset, int] = UNSET
    count_goalkeeper_save_diving: Union[Unset, int] = UNSET
    count_goalkeeper_save_down_to_knees: Union[Unset, int] = UNSET
    count_goalkeeper_save_tilting: Union[Unset, int] = UNSET
    count_group_counter_pressing: Union[Unset, int] = UNSET
    count_group_empty_goal_handball: Union[Unset, int] = UNSET
    count_heart_rate_recovery: Union[Unset, int] = UNSET
    count_impact: Union[Unset, int] = UNSET
    count_jump_beach_volleyball: Union[Unset, int] = UNSET
    count_jump: Union[Unset, int] = UNSET
    count_mid_court_transition: Union[Unset, int] = UNSET
    count_noah_shot: Union[Unset, int] = UNSET
    count_offence: Union[Unset, int] = UNSET
    count_pass_fifa: Union[Unset, int] = UNSET
    count_pick_and_pop: Union[Unset, int] = UNSET
    count_pick_and_roll: Union[Unset, int] = UNSET
    count_pivot_rotation: Union[Unset, int] = UNSET
    count_play_by_player: Union[Unset, int] = UNSET
    count_play_by_team: Union[Unset, int] = UNSET
    count_player_counter_pressing: Union[Unset, int] = UNSET
    count_rally_beach_volleyball: Union[Unset, int] = UNSET
    count_rspct_shot: Union[Unset, int] = UNSET
    count_shift: Union[Unset, int] = UNSET
    count_skating_transition: Union[Unset, int] = UNSET
    count_speed_zone_entry: Union[Unset, int] = UNSET
    count_speed_zone_entry_relative: Union[Unset, int] = UNSET
    count_sprint: Union[Unset, int] = UNSET
    count_tag: Union[Unset, int] = UNSET
    count_tempo_run: Union[Unset, int] = UNSET
    count_throw_in: Union[Unset, int] = UNSET
    count_turn_ice_hockey: Union[Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        count_acceleration = self.count_acceleration

        count_ball_contact = self.count_ball_contact

        count_ball_possession = self.count_ball_possession

        count_ball_possession_lost = self.count_ball_possession_lost

        count_ball_possession_recovery = self.count_ball_possession_recovery

        count_cv_shot = self.count_cv_shot

        count_change_of_direction = self.count_change_of_direction

        count_change_of_orientation = self.count_change_of_orientation

        count_change_of_pace = self.count_change_of_pace

        count_corner_kick = self.count_corner_kick

        count_counter_attack = self.count_counter_attack

        count_detected_cross = self.count_detected_cross

        count_cut = self.count_cut

        count_deceleration = self.count_deceleration

        count_defence = self.count_defence

        count_detected_offside_soccer = self.count_detected_offside_soccer

        count_detected_pass = self.count_detected_pass

        count_detected_shot_basketball = self.count_detected_shot_basketball

        count_detected_shot_fifa = self.count_detected_shot_fifa

        count_detected_shot_handball = self.count_detected_shot_handball

        count_detected_shot_ice_hockey = self.count_detected_shot_ice_hockey

        count_detected_shot_intelligence_court = self.count_detected_shot_intelligence_court

        count_detected_shot_soccer = self.count_detected_shot_soccer

        count_dfl_corner_kick = self.count_dfl_corner_kick

        count_dfl_cross = self.count_dfl_cross

        count_dfl_free_kick = self.count_dfl_free_kick

        count_dfl_goal_kick = self.count_dfl_goal_kick

        count_dfl_kick_off = self.count_dfl_kick_off

        count_dfl_pass = self.count_dfl_pass

        count_dfl_penalty = self.count_dfl_penalty

        count_dfl_shot_at_goal = self.count_dfl_shot_at_goal

        count_dfl_sprint = self.count_dfl_sprint

        count_dfl_tackling = self.count_dfl_tackling

        count_dfl_throw_in = self.count_dfl_throw_in

        count_down_on_pads = self.count_down_on_pads

        count_dribbling_soccer = self.count_dribbling_soccer

        count_dynamic_defence = self.count_dynamic_defence

        count_exertion = self.count_exertion

        count_full_court_transition = self.count_full_court_transition

        count_goal_kick = self.count_goal_kick

        count_goalkeeper_save_diving = self.count_goalkeeper_save_diving

        count_goalkeeper_save_down_to_knees = self.count_goalkeeper_save_down_to_knees

        count_goalkeeper_save_tilting = self.count_goalkeeper_save_tilting

        count_group_counter_pressing = self.count_group_counter_pressing

        count_group_empty_goal_handball = self.count_group_empty_goal_handball

        count_heart_rate_recovery = self.count_heart_rate_recovery

        count_impact = self.count_impact

        count_jump_beach_volleyball = self.count_jump_beach_volleyball

        count_jump = self.count_jump

        count_mid_court_transition = self.count_mid_court_transition

        count_noah_shot = self.count_noah_shot

        count_offence = self.count_offence

        count_pass_fifa = self.count_pass_fifa

        count_pick_and_pop = self.count_pick_and_pop

        count_pick_and_roll = self.count_pick_and_roll

        count_pivot_rotation = self.count_pivot_rotation

        count_play_by_player = self.count_play_by_player

        count_play_by_team = self.count_play_by_team

        count_player_counter_pressing = self.count_player_counter_pressing

        count_rally_beach_volleyball = self.count_rally_beach_volleyball

        count_rspct_shot = self.count_rspct_shot

        count_shift = self.count_shift

        count_skating_transition = self.count_skating_transition

        count_speed_zone_entry = self.count_speed_zone_entry

        count_speed_zone_entry_relative = self.count_speed_zone_entry_relative

        count_sprint = self.count_sprint

        count_tag = self.count_tag

        count_tempo_run = self.count_tempo_run

        count_throw_in = self.count_throw_in

        count_turn_ice_hockey = self.count_turn_ice_hockey

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if count_acceleration is not UNSET:
            field_dict["count_acceleration"] = count_acceleration
        if count_ball_contact is not UNSET:
            field_dict["count_ball_contact"] = count_ball_contact
        if count_ball_possession is not UNSET:
            field_dict["count_ball_possession"] = count_ball_possession
        if count_ball_possession_lost is not UNSET:
            field_dict["count_ball_possession_lost"] = count_ball_possession_lost
        if count_ball_possession_recovery is not UNSET:
            field_dict["count_ball_possession_recovery"] = count_ball_possession_recovery
        if count_cv_shot is not UNSET:
            field_dict["count_cv_shot"] = count_cv_shot
        if count_change_of_direction is not UNSET:
            field_dict["count_change_of_direction"] = count_change_of_direction
        if count_change_of_orientation is not UNSET:
            field_dict["count_change_of_orientation"] = count_change_of_orientation
        if count_change_of_pace is not UNSET:
            field_dict["count_change_of_pace"] = count_change_of_pace
        if count_corner_kick is not UNSET:
            field_dict["count_corner_kick"] = count_corner_kick
        if count_counter_attack is not UNSET:
            field_dict["count_counter_attack"] = count_counter_attack
        if count_detected_cross is not UNSET:
            field_dict["count_detected_cross"] = count_detected_cross
        if count_cut is not UNSET:
            field_dict["count_cut"] = count_cut
        if count_deceleration is not UNSET:
            field_dict["count_deceleration"] = count_deceleration
        if count_defence is not UNSET:
            field_dict["count_defence"] = count_defence
        if count_detected_offside_soccer is not UNSET:
            field_dict["count_detected_offside_soccer"] = count_detected_offside_soccer
        if count_detected_pass is not UNSET:
            field_dict["count_detected_pass"] = count_detected_pass
        if count_detected_shot_basketball is not UNSET:
            field_dict["count_detected_shot_basketball"] = count_detected_shot_basketball
        if count_detected_shot_fifa is not UNSET:
            field_dict["count_detected_shot_fifa"] = count_detected_shot_fifa
        if count_detected_shot_handball is not UNSET:
            field_dict["count_detected_shot_handball"] = count_detected_shot_handball
        if count_detected_shot_ice_hockey is not UNSET:
            field_dict["count_detected_shot_ice_hockey"] = count_detected_shot_ice_hockey
        if count_detected_shot_intelligence_court is not UNSET:
            field_dict["count_detected_shot_intelligence_court"] = count_detected_shot_intelligence_court
        if count_detected_shot_soccer is not UNSET:
            field_dict["count_detected_shot_soccer"] = count_detected_shot_soccer
        if count_dfl_corner_kick is not UNSET:
            field_dict["count_dfl_corner_kick"] = count_dfl_corner_kick
        if count_dfl_cross is not UNSET:
            field_dict["count_dfl_cross"] = count_dfl_cross
        if count_dfl_free_kick is not UNSET:
            field_dict["count_dfl_free_kick"] = count_dfl_free_kick
        if count_dfl_goal_kick is not UNSET:
            field_dict["count_dfl_goal_kick"] = count_dfl_goal_kick
        if count_dfl_kick_off is not UNSET:
            field_dict["count_dfl_kick_off"] = count_dfl_kick_off
        if count_dfl_pass is not UNSET:
            field_dict["count_dfl_pass"] = count_dfl_pass
        if count_dfl_penalty is not UNSET:
            field_dict["count_dfl_penalty"] = count_dfl_penalty
        if count_dfl_shot_at_goal is not UNSET:
            field_dict["count_dfl_shot_at_goal"] = count_dfl_shot_at_goal
        if count_dfl_sprint is not UNSET:
            field_dict["count_dfl_sprint"] = count_dfl_sprint
        if count_dfl_tackling is not UNSET:
            field_dict["count_dfl_tackling"] = count_dfl_tackling
        if count_dfl_throw_in is not UNSET:
            field_dict["count_dfl_throw_in"] = count_dfl_throw_in
        if count_down_on_pads is not UNSET:
            field_dict["count_down_on_pads"] = count_down_on_pads
        if count_dribbling_soccer is not UNSET:
            field_dict["count_dribbling_soccer"] = count_dribbling_soccer
        if count_dynamic_defence is not UNSET:
            field_dict["count_dynamic_defence"] = count_dynamic_defence
        if count_exertion is not UNSET:
            field_dict["count_exertion"] = count_exertion
        if count_full_court_transition is not UNSET:
            field_dict["count_full_court_transition"] = count_full_court_transition
        if count_goal_kick is not UNSET:
            field_dict["count_goal_kick"] = count_goal_kick
        if count_goalkeeper_save_diving is not UNSET:
            field_dict["count_goalkeeper_save_diving"] = count_goalkeeper_save_diving
        if count_goalkeeper_save_down_to_knees is not UNSET:
            field_dict["count_goalkeeper_save_down_to_knees"] = count_goalkeeper_save_down_to_knees
        if count_goalkeeper_save_tilting is not UNSET:
            field_dict["count_goalkeeper_save_tilting"] = count_goalkeeper_save_tilting
        if count_group_counter_pressing is not UNSET:
            field_dict["count_group_counter_pressing"] = count_group_counter_pressing
        if count_group_empty_goal_handball is not UNSET:
            field_dict["count_group_empty_goal_handball"] = count_group_empty_goal_handball
        if count_heart_rate_recovery is not UNSET:
            field_dict["count_heart_rate_recovery"] = count_heart_rate_recovery
        if count_impact is not UNSET:
            field_dict["count_impact"] = count_impact
        if count_jump_beach_volleyball is not UNSET:
            field_dict["count_jump_beach_volleyball"] = count_jump_beach_volleyball
        if count_jump is not UNSET:
            field_dict["count_jump"] = count_jump
        if count_mid_court_transition is not UNSET:
            field_dict["count_mid_court_transition"] = count_mid_court_transition
        if count_noah_shot is not UNSET:
            field_dict["count_noah_shot"] = count_noah_shot
        if count_offence is not UNSET:
            field_dict["count_offence"] = count_offence
        if count_pass_fifa is not UNSET:
            field_dict["count_pass_fifa"] = count_pass_fifa
        if count_pick_and_pop is not UNSET:
            field_dict["count_pick_and_pop"] = count_pick_and_pop
        if count_pick_and_roll is not UNSET:
            field_dict["count_pick_and_roll"] = count_pick_and_roll
        if count_pivot_rotation is not UNSET:
            field_dict["count_pivot_rotation"] = count_pivot_rotation
        if count_play_by_player is not UNSET:
            field_dict["count_play_by_player"] = count_play_by_player
        if count_play_by_team is not UNSET:
            field_dict["count_play_by_team"] = count_play_by_team
        if count_player_counter_pressing is not UNSET:
            field_dict["count_player_counter_pressing"] = count_player_counter_pressing
        if count_rally_beach_volleyball is not UNSET:
            field_dict["count_rally_beach_volleyball"] = count_rally_beach_volleyball
        if count_rspct_shot is not UNSET:
            field_dict["count_rspct_shot"] = count_rspct_shot
        if count_shift is not UNSET:
            field_dict["count_shift"] = count_shift
        if count_skating_transition is not UNSET:
            field_dict["count_skating_transition"] = count_skating_transition
        if count_speed_zone_entry is not UNSET:
            field_dict["count_speed_zone_entry"] = count_speed_zone_entry
        if count_speed_zone_entry_relative is not UNSET:
            field_dict["count_speed_zone_entry_relative"] = count_speed_zone_entry_relative
        if count_sprint is not UNSET:
            field_dict["count_sprint"] = count_sprint
        if count_tag is not UNSET:
            field_dict["count_tag"] = count_tag
        if count_tempo_run is not UNSET:
            field_dict["count_tempo_run"] = count_tempo_run
        if count_throw_in is not UNSET:
            field_dict["count_throw_in"] = count_throw_in
        if count_turn_ice_hockey is not UNSET:
            field_dict["count_turn_ice_hockey"] = count_turn_ice_hockey

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        count_acceleration = d.pop("count_acceleration", UNSET)

        count_ball_contact = d.pop("count_ball_contact", UNSET)

        count_ball_possession = d.pop("count_ball_possession", UNSET)

        count_ball_possession_lost = d.pop("count_ball_possession_lost", UNSET)

        count_ball_possession_recovery = d.pop("count_ball_possession_recovery", UNSET)

        count_cv_shot = d.pop("count_cv_shot", UNSET)

        count_change_of_direction = d.pop("count_change_of_direction", UNSET)

        count_change_of_orientation = d.pop("count_change_of_orientation", UNSET)

        count_change_of_pace = d.pop("count_change_of_pace", UNSET)

        count_corner_kick = d.pop("count_corner_kick", UNSET)

        count_counter_attack = d.pop("count_counter_attack", UNSET)

        count_detected_cross = d.pop("count_detected_cross", UNSET)

        count_cut = d.pop("count_cut", UNSET)

        count_deceleration = d.pop("count_deceleration", UNSET)

        count_defence = d.pop("count_defence", UNSET)

        count_detected_offside_soccer = d.pop("count_detected_offside_soccer", UNSET)

        count_detected_pass = d.pop("count_detected_pass", UNSET)

        count_detected_shot_basketball = d.pop("count_detected_shot_basketball", UNSET)

        count_detected_shot_fifa = d.pop("count_detected_shot_fifa", UNSET)

        count_detected_shot_handball = d.pop("count_detected_shot_handball", UNSET)

        count_detected_shot_ice_hockey = d.pop("count_detected_shot_ice_hockey", UNSET)

        count_detected_shot_intelligence_court = d.pop("count_detected_shot_intelligence_court", UNSET)

        count_detected_shot_soccer = d.pop("count_detected_shot_soccer", UNSET)

        count_dfl_corner_kick = d.pop("count_dfl_corner_kick", UNSET)

        count_dfl_cross = d.pop("count_dfl_cross", UNSET)

        count_dfl_free_kick = d.pop("count_dfl_free_kick", UNSET)

        count_dfl_goal_kick = d.pop("count_dfl_goal_kick", UNSET)

        count_dfl_kick_off = d.pop("count_dfl_kick_off", UNSET)

        count_dfl_pass = d.pop("count_dfl_pass", UNSET)

        count_dfl_penalty = d.pop("count_dfl_penalty", UNSET)

        count_dfl_shot_at_goal = d.pop("count_dfl_shot_at_goal", UNSET)

        count_dfl_sprint = d.pop("count_dfl_sprint", UNSET)

        count_dfl_tackling = d.pop("count_dfl_tackling", UNSET)

        count_dfl_throw_in = d.pop("count_dfl_throw_in", UNSET)

        count_down_on_pads = d.pop("count_down_on_pads", UNSET)

        count_dribbling_soccer = d.pop("count_dribbling_soccer", UNSET)

        count_dynamic_defence = d.pop("count_dynamic_defence", UNSET)

        count_exertion = d.pop("count_exertion", UNSET)

        count_full_court_transition = d.pop("count_full_court_transition", UNSET)

        count_goal_kick = d.pop("count_goal_kick", UNSET)

        count_goalkeeper_save_diving = d.pop("count_goalkeeper_save_diving", UNSET)

        count_goalkeeper_save_down_to_knees = d.pop("count_goalkeeper_save_down_to_knees", UNSET)

        count_goalkeeper_save_tilting = d.pop("count_goalkeeper_save_tilting", UNSET)

        count_group_counter_pressing = d.pop("count_group_counter_pressing", UNSET)

        count_group_empty_goal_handball = d.pop("count_group_empty_goal_handball", UNSET)

        count_heart_rate_recovery = d.pop("count_heart_rate_recovery", UNSET)

        count_impact = d.pop("count_impact", UNSET)

        count_jump_beach_volleyball = d.pop("count_jump_beach_volleyball", UNSET)

        count_jump = d.pop("count_jump", UNSET)

        count_mid_court_transition = d.pop("count_mid_court_transition", UNSET)

        count_noah_shot = d.pop("count_noah_shot", UNSET)

        count_offence = d.pop("count_offence", UNSET)

        count_pass_fifa = d.pop("count_pass_fifa", UNSET)

        count_pick_and_pop = d.pop("count_pick_and_pop", UNSET)

        count_pick_and_roll = d.pop("count_pick_and_roll", UNSET)

        count_pivot_rotation = d.pop("count_pivot_rotation", UNSET)

        count_play_by_player = d.pop("count_play_by_player", UNSET)

        count_play_by_team = d.pop("count_play_by_team", UNSET)

        count_player_counter_pressing = d.pop("count_player_counter_pressing", UNSET)

        count_rally_beach_volleyball = d.pop("count_rally_beach_volleyball", UNSET)

        count_rspct_shot = d.pop("count_rspct_shot", UNSET)

        count_shift = d.pop("count_shift", UNSET)

        count_skating_transition = d.pop("count_skating_transition", UNSET)

        count_speed_zone_entry = d.pop("count_speed_zone_entry", UNSET)

        count_speed_zone_entry_relative = d.pop("count_speed_zone_entry_relative", UNSET)

        count_sprint = d.pop("count_sprint", UNSET)

        count_tag = d.pop("count_tag", UNSET)

        count_tempo_run = d.pop("count_tempo_run", UNSET)

        count_throw_in = d.pop("count_throw_in", UNSET)

        count_turn_ice_hockey = d.pop("count_turn_ice_hockey", UNSET)

        event_count = cls(
            count_acceleration=count_acceleration,
            count_ball_contact=count_ball_contact,
            count_ball_possession=count_ball_possession,
            count_ball_possession_lost=count_ball_possession_lost,
            count_ball_possession_recovery=count_ball_possession_recovery,
            count_cv_shot=count_cv_shot,
            count_change_of_direction=count_change_of_direction,
            count_change_of_orientation=count_change_of_orientation,
            count_change_of_pace=count_change_of_pace,
            count_corner_kick=count_corner_kick,
            count_counter_attack=count_counter_attack,
            count_detected_cross=count_detected_cross,
            count_cut=count_cut,
            count_deceleration=count_deceleration,
            count_defence=count_defence,
            count_detected_offside_soccer=count_detected_offside_soccer,
            count_detected_pass=count_detected_pass,
            count_detected_shot_basketball=count_detected_shot_basketball,
            count_detected_shot_fifa=count_detected_shot_fifa,
            count_detected_shot_handball=count_detected_shot_handball,
            count_detected_shot_ice_hockey=count_detected_shot_ice_hockey,
            count_detected_shot_intelligence_court=count_detected_shot_intelligence_court,
            count_detected_shot_soccer=count_detected_shot_soccer,
            count_dfl_corner_kick=count_dfl_corner_kick,
            count_dfl_cross=count_dfl_cross,
            count_dfl_free_kick=count_dfl_free_kick,
            count_dfl_goal_kick=count_dfl_goal_kick,
            count_dfl_kick_off=count_dfl_kick_off,
            count_dfl_pass=count_dfl_pass,
            count_dfl_penalty=count_dfl_penalty,
            count_dfl_shot_at_goal=count_dfl_shot_at_goal,
            count_dfl_sprint=count_dfl_sprint,
            count_dfl_tackling=count_dfl_tackling,
            count_dfl_throw_in=count_dfl_throw_in,
            count_down_on_pads=count_down_on_pads,
            count_dribbling_soccer=count_dribbling_soccer,
            count_dynamic_defence=count_dynamic_defence,
            count_exertion=count_exertion,
            count_full_court_transition=count_full_court_transition,
            count_goal_kick=count_goal_kick,
            count_goalkeeper_save_diving=count_goalkeeper_save_diving,
            count_goalkeeper_save_down_to_knees=count_goalkeeper_save_down_to_knees,
            count_goalkeeper_save_tilting=count_goalkeeper_save_tilting,
            count_group_counter_pressing=count_group_counter_pressing,
            count_group_empty_goal_handball=count_group_empty_goal_handball,
            count_heart_rate_recovery=count_heart_rate_recovery,
            count_impact=count_impact,
            count_jump_beach_volleyball=count_jump_beach_volleyball,
            count_jump=count_jump,
            count_mid_court_transition=count_mid_court_transition,
            count_noah_shot=count_noah_shot,
            count_offence=count_offence,
            count_pass_fifa=count_pass_fifa,
            count_pick_and_pop=count_pick_and_pop,
            count_pick_and_roll=count_pick_and_roll,
            count_pivot_rotation=count_pivot_rotation,
            count_play_by_player=count_play_by_player,
            count_play_by_team=count_play_by_team,
            count_player_counter_pressing=count_player_counter_pressing,
            count_rally_beach_volleyball=count_rally_beach_volleyball,
            count_rspct_shot=count_rspct_shot,
            count_shift=count_shift,
            count_skating_transition=count_skating_transition,
            count_speed_zone_entry=count_speed_zone_entry,
            count_speed_zone_entry_relative=count_speed_zone_entry_relative,
            count_sprint=count_sprint,
            count_tag=count_tag,
            count_tempo_run=count_tempo_run,
            count_throw_in=count_throw_in,
            count_turn_ice_hockey=count_turn_ice_hockey,
        )

        event_count.additional_properties = d
        return event_count

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class EventDflPenaltySuccessful(str, Enum):
    DFL_PENALTY_MISSED = "dfl_penalty_missed"
    DFL_PENALTY_SUCCESSFUL = "dfl_penalty_successful"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class EventDribblingSoccerDribblingSoccerCategory(str, Enum):
    BALL_HOLDING = "ball_holding"
    OVERCOME_OPPONENT = "overcome_opponent"
    TEMPO = "tempo"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class PlayerStatisticFieldsItem(str, Enum):
    ACCEL_AVG = "accel_avg"
    ACCEL_LOAD_ACCUM = "accel_load_accum"
    ACCEL_LOAD_ACCUM_AVG_PER_MINUTE = "accel_load_accum_avg_per_minute"
    ACCEL_LOAD_AVG = "accel_load_avg"
    ACCEL_LOAD_MAX = "accel_load_max"
    ACCEL_MAX = "accel_max"
    ACCEL_MIN = "accel_min"
    ACTIVE_GAME_TIME = "active_game_time"
    BALL_CONTACT_COUNT = "ball_contact_count"
    BALL_CONTACT_COUNT_AVG_PER_MINUTE = "ball_contact_count_avg_per_minute"
    DATA_AVAILABILITY = "data_availability"
    DATA_QUALITY = "data_quality"
    DISTANCE_ACCELERATION_LOAD_CATEGORY1 = "distance_acceleration_load_category1"
    DISTANCE_ACCELERATION_LOAD_CATEGORY2 = "distance_acceleration_load_category2"
    DISTANCE_ACCELERATION_LOAD_CATEGORY3 = "distance_acceleration_load_category3"
    DISTANCE_ACCELERATION_LOAD_CATEGORY4 = "distance_acceleration_load_category4"
    DISTANCE_ACCELERATION_LOAD_CATEGORY5 = "distance_acceleration_load_category5"
    DISTANCE_ACCELERATION_LOAD_CATEGORY6 = "distance_acceleration_load_category6"
    DISTANCE_ACCELERATION_LOAD_CATEGORY7 = "distance_acceleration_load_category7"
    DISTANCE_ANAEROBIC_ACTIVITY = "distance_anaerobic_activity"
    DISTANCE_BACKWARD = "distance_backward"
    DISTANCE_FORWARD = "distance_forward"
    DISTANCE_FROM_STEPS = "distance_from_steps"
    DISTANCE_FROM_STEPS_AVG_PER_MINUTE = "distance_from_steps_avg_per_minute"
    DISTANCE_GLIDING_SPEED_CATEGORY1 = "distance_gliding_speed_category1"
    DISTANCE_GLIDING_SPEED_CATEGORY1_AVG_PER_MINUTE = "distance_gliding_speed_category1_avg_per_minute"
    DISTANCE_GLIDING_SPEED_CATEGORY2 = "distance_gliding_speed_category2"
    DISTANCE_GLIDING_SPEED_CATEGORY2_AVG_PER_MINUTE = "distance_gliding_speed_category2_avg_per_minute"
    DISTANCE_GLIDING_SPEED_CATEGORY3 = "distance_gliding_speed_category3"
    DISTANCE_GLIDING_SPEED_CATEGORY3_AVG_PER_MINUTE = "distance_gliding_speed_category3_avg_per_minute"
    DISTANCE_GLIDING_SPEED_CATEGORY4 = "distance_gliding_speed_category4"
    DISTANCE_GLIDING_SPEED_CATEGORY4_AVG_PER_MINUTE = "distance_gliding_speed_category4_avg_per_minute"
    DISTANCE_GLIDING_SPEED_CATEGORY5 = "distance_gliding_speed_category5"
    DISTANCE_GLIDING_SPEED_CATEGORY5_AVG_PER_MINUTE = "distance_gliding_speed_category5_avg_per_minute"
    DISTANCE_GLIDING_SPEED_CATEGORY6 = "distance_gliding_speed_category6"
    DISTANCE_GLIDING_SPEED_CATEGORY6_AVG_PER_MINUTE = "distance_gliding_speed_category6_avg_per_minute"
    DISTANCE_GLIDING_SPEED_CATEGORY7 = "distance_gliding_speed_category7"
    DISTANCE_GLIDING_SPEED_CATEGORY7_AVG_PER_MINUTE = "distance_gliding_speed_category7_avg_per_minute"
    DISTANCE_HIGH_METABOLIC_LOAD = "distance_high_metabolic_load"
    DISTANCE_HIGH_METABOLIC_LOAD_AVG_PER_MINUTE = "distance_high_metabolic_load_avg_per_minute"
    DISTANCE_HIGH_METABOLIC_POWER = "distance_high_metabolic_power"
    DISTANCE_HIGH_METABOLIC_POWER_AVG_PER_MINUTE = "distance_high_metabolic_power_avg_per_minute"
    DISTANCE_LEFT = "distance_left"
    DISTANCE_RIGHT = "distance_right"
    DISTANCE_SKATING_SPEED_CATEGORY1 = "distance_skating_speed_category1"
    DISTANCE_SKATING_SPEED_CATEGORY1_AVG_PER_MINUTE = "distance_skating_speed_category1_avg_per_minute"
    DISTANCE_SKATING_SPEED_CATEGORY2 = "distance_skating_speed_category2"
    DISTANCE_SKATING_SPEED_CATEGORY2_AVG_PER_MINUTE = "distance_skating_speed_category2_avg_per_minute"
    DISTANCE_SKATING_SPEED_CATEGORY3 = "distance_skating_speed_category3"
    DISTANCE_SKATING_SPEED_CATEGORY3_AVG_PER_MINUTE = "distance_skating_speed_category3_avg_per_minute"
    DISTANCE_SKATING_SPEED_CATEGORY4 = "distance_skating_speed_category4"
    DISTANCE_SKATING_SPEED_CATEGORY4_AVG_PER_MINUTE = "distance_skating_speed_category4_avg_per_minute"
    DISTANCE_SKATING_SPEED_CATEGORY5 = "distance_skating_speed_category5"
    DISTANCE_SKATING_SPEED_CATEGORY5_AVG_PER_MINUTE = "distance_skating_speed_category5_avg_per_minute"
    DISTANCE_SKATING_SPEED_CATEGORY6 = "distance_skating_speed_category6"
    DISTANCE_SKATING_SPEED_CATEGORY6_AVG_PER_MINUTE = "distance_skating_speed_category6_avg_per_minute"
    DISTANCE_SKATING_SPEED_CATEGORY7 = "distance_skating_speed_category7"
    DISTANCE_SKATING_SPEED_CATEGORY7_AVG_PER_MINUTE = "distance_skating_speed_category7_avg_per_minute"
    DISTANCE_SPEED_CATEGORY1 = "distance_speed_category1"
    DISTANCE_SPEED_CATEGORY1_AVG_PER_MINUTE = "distance_speed_category1_avg_per_minute"
    DISTANCE_SPEED_CATEGORY2 = "distance_speed_category2"
    DISTANCE_SPEED_CATEGORY2_AVG_PER_MINUTE = "distance_speed_category2_avg_per_minute"
    DISTANCE_SPEED_CATEGORY3 = "distance_speed_category3"
    DISTANCE_SPEED_CATEGORY3_AVG_PER_MINUTE = "distance_speed_category3_avg_per_minute"
    DISTANCE_SPEED_CATEGORY4 = "distance_speed_category4"
    DISTANCE_SPEED_CATEGORY4_AVG_PER_MINUTE = "distance_speed_category4_avg_per_minute"
    DISTANCE_SPEED_CATEGORY5 = "distance_speed_category5"
    DISTANCE_SPEED_CATEGORY5_AVG_PER_MINUTE = "distance_speed_category5_avg_per_minute"
    DISTANCE_SPEED_CATEGORY6 = "distance_speed_category6"
    DISTANCE_SPEED_CATEGORY6_AVG_PER_MINUTE = "distance_speed_category6_avg_per_minute"
    DISTANCE_SPEED_CATEGORY7 = "distance_speed_category7"
    DISTANCE_SPEED_CATEGORY7_AVG_PER_MINUTE = "distance_speed_category7_avg_per_minute"
    DISTANCE_SPEED_RELATIVE_CATEGORY1 = "distance_speed_relative_category1"
    DISTANCE_SPEED_RELATIVE_CATEGORY1_AVG_PER_MINUTE = "distance_speed_relative_category1_avg_per_minute"
    DISTANCE_SPEED_RELATIVE_CATEGORY2 = "distance_speed_relative_category2"
    DISTANCE_SPEED_RELATIVE_CATEGORY2_AVG_PER_MINUTE = "distance_speed_relative_category2_avg_per_minute"
    DISTANCE_SPEED_RELATIVE_CATEGORY3 = "distance_speed_relative_category3"
    DISTANCE_SPEED_RELATIVE_CATEGORY3_AVG_PER_MINUTE = "distance_speed_relative_category3_avg_per_minute"
    DISTANCE_SPEED_RELATIVE_CATEGORY4 = "distance_speed_relative_category4"
    DISTANCE_SPEED_RELATIVE_CATEGORY4_AVG_PER_MINUTE = "distance_speed_relative_category4_avg_per_minute"
    DISTANCE_SPEED_RELATIVE_CATEGORY5 = "distance_speed_relative_category5"
    DISTANCE_SPEED_RELATIVE_CATEGORY5_AVG_PER_MINUTE = "distance_speed_relative_category5_avg_per_minute"
    DISTANCE_SPEED_RELATIVE_CATEGORY6 = "distance_speed_relative_category6"
    DISTANCE_SPEED_RELATIVE_CATEGORY6_AVG_PER_MINUTE = "distance_speed_relative_category6_avg_per_minute"
    DISTANCE_SPEED_RELATIVE_CATEGORY7 = "distance_speed_relative_category7"
    DISTANCE_SPEED_RELATIVE_CATEGORY7_AVG_PER_MINUTE = "distance_speed_relative_category7_avg_per_minute"
    DISTANCE_TOTAL = "distance_total"
    DISTANCE_TOTAL_AVG_PER_MINUTE = "distance_total_avg_per_minute"
    DISTANCE_TOTAL_GLIDING = "distance_total_gliding"
    DISTANCE_TOTAL_GLIDING_AVG_PER_MINUTE = "distance_total_gliding_avg_per_minute"
    DISTANCE_TOTAL_RELATIVE = "distance_total_relative"
    DISTANCE_TOTAL_RELATIVE_AVG_PER_MINUTE = "distance_total_relative_avg_per_minute"
    DISTANCE_TOTAL_SKATING = "distance_total_skating"
    DISTANCE_TOTAL_SKATING_AVG_PER_MINUTE = "distance_total_skating_avg_per_minute"
    DISTANCE_UNKNOWN = "distance_unknown"
    HEART_RATE_AVG = "heart_rate_avg"
    HEART_RATE_IMPULSE = "heart_rate_impulse"
    HEART_RATE_MAX = "heart_rate_max"
    HEART_RATE_MIN = "heart_rate_min"
    HUMAN_CORE_TEMPERATURE_AVG = "human_core_temperature_avg"
    HUMAN_CORE_TEMPERATURE_MAX = "human_core_temperature_max"
    IMU_FLAG = "imu_flag"
    IMU_MISSING_RECORDING_RATIO = "imu_missing_recording_ratio"
    JUMP_HEIGHT_MAX = "jump_height_max"
    JUMP_LOAD = "jump_load"
    JUMP_LOAD_AVG_PER_MINUTE = "jump_load_avg_per_minute"
    JUMP_LOAD_PER_MASS = "jump_load_per_mass"
    JUMP_LOAD_PER_MASS_AVG_PER_MINUTE = "jump_load_per_mass_avg_per_minute"
    LOAD_ACCELERATION_LOAD_CATEGORY1 = "load_acceleration_load_category1"
    LOAD_ACCELERATION_LOAD_CATEGORY1_AVG_PER_MINUTE = "load_acceleration_load_category1_avg_per_minute"
    LOAD_ACCELERATION_LOAD_CATEGORY2 = "load_acceleration_load_category2"
    LOAD_ACCELERATION_LOAD_CATEGORY2_AVG_PER_MINUTE = "load_acceleration_load_category2_avg_per_minute"
    LOAD_ACCELERATION_LOAD_CATEGORY3 = "load_acceleration_load_category3"
    LOAD_ACCELERATION_LOAD_CATEGORY3_AVG_PER_MINUTE = "load_acceleration_load_category3_avg_per_minute"
    LOAD_ACCELERATION_LOAD_CATEGORY4 = "load_acceleration_load_category4"
    LOAD_ACCELERATION_LOAD_CATEGORY4_AVG_PER_MINUTE = "load_acceleration_load_category4_avg_per_minute"
    LOAD_ACCELERATION_LOAD_CATEGORY5 = "load_acceleration_load_category5"
    LOAD_ACCELERATION_LOAD_CATEGORY5_AVG_PER_MINUTE = "load_acceleration_load_category5_avg_per_minute"
    LOAD_ACCELERATION_LOAD_CATEGORY6 = "load_acceleration_load_category6"
    LOAD_ACCELERATION_LOAD_CATEGORY6_AVG_PER_MINUTE = "load_acceleration_load_category6_avg_per_minute"
    LOAD_ACCELERATION_LOAD_CATEGORY7 = "load_acceleration_load_category7"
    LOAD_ACCELERATION_LOAD_CATEGORY7_AVG_PER_MINUTE = "load_acceleration_load_category7_avg_per_minute"
    MECHANICAL_ACCEL_CATEGORY1 = "mechanical_accel_category1"
    MECHANICAL_ACCEL_CATEGORY1_AVG_PER_MINUTE = "mechanical_accel_category1_avg_per_minute"
    MECHANICAL_ACCEL_CATEGORY2 = "mechanical_accel_category2"
    MECHANICAL_ACCEL_CATEGORY2_AVG_PER_MINUTE = "mechanical_accel_category2_avg_per_minute"
    MECHANICAL_ACCEL_CATEGORY3 = "mechanical_accel_category3"
    MECHANICAL_ACCEL_CATEGORY3_AVG_PER_MINUTE = "mechanical_accel_category3_avg_per_minute"
    MECHANICAL_ACCEL_CATEGORY4 = "mechanical_accel_category4"
    MECHANICAL_ACCEL_CATEGORY4_AVG_PER_MINUTE = "mechanical_accel_category4_avg_per_minute"
    MECHANICAL_ACCEL_TOTAL = "mechanical_accel_total"
    MECHANICAL_ACCEL_TOTAL_AVG_PER_MINUTE = "mechanical_accel_total_avg_per_minute"
    MECHANICAL_DECEL_CATEGORY1 = "mechanical_decel_category1"
    MECHANICAL_DECEL_CATEGORY1_AVG_PER_MINUTE = "mechanical_decel_category1_avg_per_minute"
    MECHANICAL_DECEL_CATEGORY2 = "mechanical_decel_category2"
    MECHANICAL_DECEL_CATEGORY2_AVG_PER_MINUTE = "mechanical_decel_category2_avg_per_minute"
    MECHANICAL_DECEL_CATEGORY3 = "mechanical_decel_category3"
    MECHANICAL_DECEL_CATEGORY3_AVG_PER_MINUTE = "mechanical_decel_category3_avg_per_minute"
    MECHANICAL_DECEL_CATEGORY4 = "mechanical_decel_category4"
    MECHANICAL_DECEL_CATEGORY4_AVG_PER_MINUTE = "mechanical_decel_category4_avg_per_minute"
    MECHANICAL_DECEL_TOTAL = "mechanical_decel_total"
    MECHANICAL_DECEL_TOTAL_AVG_PER_MINUTE = "mechanical_decel_total_avg_per_minute"
    MECHANICAL_INTENSITY = "mechanical_intensity"
    MECHANICAL_INTENSITY_DEFENCE = "mechanical_intensity_defence"
    MECHANICAL_INTENSITY_OFFENCE = "mechanical_intensity_offence"
    MECHANICAL_LOAD = "mechanical_load"
    MECHANICAL_LOAD_DEFENCE = "mechanical_load_defence"
    MECHANICAL_LOAD_OFFENCE = "mechanical_load_offence"
    METABOLIC_POWER_AVG = "metabolic_power_avg"
    METABOLIC_POWER_MAX = "metabolic_power_max"
    METABOLIC_POWER_MIN = "metabolic_power_min"
    METABOLIC_POWER_PER_MASS_AVG = "metabolic_power_per_mass_avg"
    METABOLIC_POWER_PER_MASS_MAX = "metabolic_power_per_mass_max"
    METABOLIC_POWER_PER_MASS_MIN = "metabolic_power_per_mass_min"
    METABOLIC_WORK = "metabolic_work"
    METABOLIC_WORK_AVG_PER_MINUTE = "metabolic_work_avg_per_minute"
    NUMBER_OF_STEPS = "number_of_steps"
    PHYSIO_INTENSITY = "physio_intensity"
    PHYSIO_LOAD = "physio_load"
    PHYSIO_LOAD_SPEED_CATEGORY1 = "physio_load_speed_category1"
    PHYSIO_LOAD_SPEED_CATEGORY2 = "physio_load_speed_category2"
    PHYSIO_LOAD_SPEED_CATEGORY3 = "physio_load_speed_category3"
    PHYSIO_LOAD_SPEED_CATEGORY4 = "physio_load_speed_category4"
    PHYSIO_LOAD_SPEED_CATEGORY5 = "physio_load_speed_category5"
    PHYSIO_LOAD_SPEED_CATEGORY6 = "physio_load_speed_category6"
    PHYSIO_LOAD_SPEED_CATEGORY7 = "physio_load_speed_category7"
    PLAYOFF_LOAD = "playoff_load"
    SPEED_AVG = "speed_avg"
    SPEED_MAX = "speed_max"
    SPEED_MIN = "speed_min"
    STEP_BALANCE_AVG = "step_balance_avg"
    TIME_ACCELERATION_LOAD_CATEGORY1 = "time_acceleration_load_category1"
    TIME_ACCELERATION_LOAD_CATEGORY2 = "time_acceleration_load_category2"
    TIME_ACCELERATION_LOAD_CATEGORY3 = "time_acceleration_load_category3"
    TIME_ACCELERATION_LOAD_CATEGORY4 = "time_acceleration_load_category4"
    TIME_ACCELERATION_LOAD_CATEGORY5 = "time_acceleration_load_category5"
    TIME_ACCELERATION_LOAD_CATEGORY6 = "time_acceleration_load_category6"
    TIME_ACCELERATION_LOAD_CATEGORY7 = "time_acceleration_load_category7"
    TIME_ANAEROBIC_ACTIVITY = "time_anaerobic_activity"
    TIME_BALL_POSSESSION = "time_ball_possession"
    TIME_HEART_RATE_CATEGORY1 = "time_heart_rate_category1"
    TIME_HEART_RATE_CATEGORY2 = "time_heart_rate_category2"
    TIME_HEART_RATE_CATEGORY3 = "time_heart_rate_category3"
    TIME_HEART_RATE_CATEGORY4 = "time_heart_rate_category4"
    TIME_HEART_RATE_CATEGORY5 = "time_heart_rate_category5"
    TIME_HEART_RATE_CATEGORY6 = "time_heart_rate_category6"
    TIME_HEART_RATE_CATEGORY7 = "time_heart_rate_category7"
    TIME_HIGH_METABOLIC_LOAD = "time_high_metabolic_load"
    TIME_IMU_DEFECTIVE = "time_imu_defective"
    TIME_METABOLIC_POWER_CATEGORY1 = "time_metabolic_power_category1"
    TIME_METABOLIC_POWER_CATEGORY2 = "time_metabolic_power_category2"
    TIME_METABOLIC_POWER_CATEGORY3 = "time_metabolic_power_category3"
    TIME_METABOLIC_POWER_CATEGORY4 = "time_metabolic_power_category4"
    TIME_METABOLIC_POWER_CATEGORY5 = "time_metabolic_power_category5"
    TIME_METABOLIC_POWER_CATEGORY6 = "time_metabolic_power_category6"
    TIME_METABOLIC_POWER_CATEGORY7 = "time_metabolic_power_category7"
    TIME_ON_PLAYING_FIELD = "time_on_playing_field"
    TIME_ON_PLAYING_FIELD_DEFENCE = "time_on_playing_field_defence"
    TIME_ON_PLAYING_FIELD_OFFENCE = "time_on_playing_field_offence"
    TIME_ON_PLAYING_FIELD_PK = "time_on_playing_field_pk"
    TIME_ON_PLAYING_FIELD_PP = "time_on_playing_field_pp"
    TIME_SPEED_CATEGORY1 = "time_speed_category1"
    TIME_SPEED_CATEGORY2 = "time_speed_category2"
    TIME_SPEED_CATEGORY3 = "time_speed_category3"
    TIME_SPEED_CATEGORY4 = "time_speed_category4"
    TIME_SPEED_CATEGORY5 = "time_speed_category5"
    TIME_SPEED_CATEGORY6 = "time_speed_category6"
    TIME_SPEED_CATEGORY7 = "time_speed_category7"
    TIME_TOTAL = "time_total"
    TIME_TOTAL_GLIDING = "time_total_gliding"
    TIME_TOTAL_SKATING = "time_total_skating"
    TIME_TOTAL_STANDING = "time_total_standing"
    TRIMP = "trimp"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class EventDflPassSuccessful(str, Enum):
    DFL_PASS_MISSED = "dfl_pass_missed"
    DFL_PASS_SUCCESSFUL = "dfl_pass_successful"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class EventDflShotAtGoalDflShotKindCategory(str, Enum):
    SHOT_AT_GOAL_BLOCKED = "shot_at_goal_blocked"
    SHOT_AT_GOAL_OTHER = "shot_at_goal_other"
    SHOT_AT_GOAL_SAVED = "shot_at_goal_saved"
    SHOT_AT_GOAL_SUCCESSFUL = "shot_at_goal_successful"
    SHOT_AT_GOAL_WIDE = "shot_at_goal_wide"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class EventDflTacklingSuccessful(str, Enum):
    DFL_TACKLING_LOST = "dfl_tackling_lost"
    DFL_TACKLING_WON = "dfl_tackling_won"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.get_statistics_by_session_id_categories_deprecated_response_200_category_names import (
        GetStatisticsBySessionIdCategoriesDeprecatedResponse200CategoryNames,
    )
    from ..models.get_statistics_by_session_id_categories_deprecated_response_200_percentage_maps import (
        GetStatisticsBySessionIdCategoriesDeprecatedResponse200PercentageMaps,
    )
    from ..models.get_statistics_by_session_id_categories_deprecated_response_200_players import (
        GetStatisticsBySessionIdCategoriesDeprecatedResponse200Players,
    )


T = TypeVar("T", bound="GetStatisticsBySessionIdCategoriesDeprecatedResponse200")


@_attrs_define
class GetStatisticsBySessionIdCategoriesDeprecatedResponse200:
    """
    Attributes:
        percentage_maps (Union[Unset, GetStatisticsBySessionIdCategoriesDeprecatedResponse200PercentageMaps]):
        category_names (Union[Unset, GetStatisticsBySessionIdCategoriesDeprecatedResponse200CategoryNames]):
        category_colors (Union[Unset, list[str]]):
        players (Union[Unset, GetStatisticsBySessionIdCategoriesDeprecatedResponse200Players]):
    """

    percentage_maps: Union[Unset, "GetStatisticsBySessionIdCategoriesDeprecatedResponse200PercentageMaps"] = UNSET
    category_names: Union[Unset, "GetStatisticsBySessionIdCategoriesDeprecatedResponse200CategoryNames"] = UNSET
    category_colors: Union[Unset, list[str]] = UNSET
    players: Union[Unset, "GetStatisticsBySessionIdCategoriesDeprecatedResponse200Players"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        percentage_maps: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.percentage_maps, Unset):
            percentage_maps = self.percentage_maps.to_dict()

        category_names: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.category_names, Unset):
            category_names = self.category_names.to_dict()

        category_colors: Union[Unset, list[str]] = UNSET
        if not isinstance(self.category_colors, Unset):
            category_colors = self.category_colors

        players: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.players, Unset):
            players = self.players.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if percentage_maps is not UNSET:
            field_dict["percentageMaps"] = percentage_maps
        if category_names is not UNSET:
            field_dict["categoryNames"] = category_names
        if category_colors is not UNSET:
            field_dict["categoryColors"] = category_colors
        if players is not UNSET:
            field_dict["players"] = players

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_statistics_by_session_id_categories_deprecated_response_200_category_names import (
            GetStatisticsBySessionIdCategoriesDeprecatedResponse200CategoryNames,
        )
        from ..models.get_statistics_by_session_id_categories_deprecated_response_200_percentage_maps import (
            GetStatisticsBySessionIdCategoriesDeprecatedResponse200PercentageMaps,
        )
        from ..models.get_statistics_by_session_id_categories_deprecated_response_200_players import (
            GetStatisticsBySessionIdCategoriesDeprecatedResponse200Players,
        )

        d = dict(src_dict)
        _percentage_maps = d.pop("percentageMaps", UNSET)
        percentage_maps: Union[Unset, GetStatisticsBySessionIdCategoriesDeprecatedResponse200PercentageMaps]
        if isinstance(_percentage_maps, Unset):
            percentage_maps = UNSET
        else:
            percentage_maps = GetStatisticsBySessionIdCategoriesDeprecatedResponse200PercentageMaps.from_dict(
                _percentage_maps
            )

        _category_names = d.pop("categoryNames", UNSET)
        category_names: Union[Unset, GetStatisticsBySessionIdCategoriesDeprecatedResponse200CategoryNames]
        if isinstance(_category_names, Unset):
            category_names = UNSET
        else:
            category_names = GetStatisticsBySessionIdCategoriesDeprecatedResponse200CategoryNames.from_dict(
                _category_names
            )

        category_colors = cast(list[str], d.pop("categoryColors", UNSET))

        _players = d.pop("players", UNSET)
        players: Union[Unset, GetStatisticsBySessionIdCategoriesDeprecatedResponse200Players]
        if isinstance(_players, Unset):
            players = UNSET
        else:
            players = GetStatisticsBySessionIdCategoriesDeprecatedResponse200Players.from_dict(_players)

        get_statistics_by_session_id_categories_deprecated_response_200 = cls(
            percentage_maps=percentage_maps,
            category_names=category_names,
            category_colors=category_colors,
            players=players,
        )

        get_statistics_by_session_id_categories_deprecated_response_200.additional_properties = d
        return get_statistics_by_session_id_categories_deprecated_response_200

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class EventChangeOfPaceChangeOfPaceCategory(str, Enum):
    CATEGORY1 = "category1"
    CATEGORY2 = "category2"
    CATEGORY3 = "category3"
    CATEGORY4 = "category4"
    CATEGORY5 = "category5"
    CATEGORY6 = "category6"
    CATEGORY7 = "category7"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.get_public_v1_statistics_by_type_by_player_id_by_time_entity_range_type_time_entity_range_type import (
    GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeTimeEntityRangeType,
)
from ...models.get_public_v1_statistics_by_type_by_player_id_by_time_entity_range_type_type import (
    GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeType,
)
from ...models.player_statistic import PlayerStatistic
from ...types import UNSET, Response, Unset


def _get_kwargs(
    type_: GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeType,
    player_id: int,
    time_entity_range_type: GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeTimeEntityRangeType,
    *,
    min_: datetime.datetime,
    max_: datetime.datetime,
    fields: Union[Unset, list[str]] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_min_ = min_.isoformat()
    params["min"] = json_min_

    json_max_ = max_.isoformat()
    params["max"] = json_max_

    json_fields: Union[Unset, list[str]] = UNSET
    if not isinstance(fields, Unset):
        json_fields = fields

    params["fields"] = json_fields

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/public/v1/statistics/{type_}/{player_id}/{time_entity_range_type}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[list["PlayerStatistic"]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = PlayerStatistic.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[list["PlayerStatistic"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    type_: GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeType,
    player_id: int,
    time_entity_range_type: GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeTimeEntityRangeType,
    *,
    client: AuthenticatedClient,
    min_: datetime.datetime,
    max_: datetime.datetime,
    fields: Union[Unset, list[str]] = UNSET,
) -> Response[list["PlayerStatistic"]]:
    """Request statistics for a range of statistics

    Args:
        type_ (GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeType):
        player_id (int):
        time_entity_range_type
            (GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeTimeEntityRangeType):
        min_ (datetime.datetime):
        max_ (datetime.datetime):
        fields (Union[Unset, list[str]]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['PlayerStatistic']]
    """

    kwargs = _get_kwargs(
        type_=type_,
        player_id=player_id,
        time_entity_range_type=time_entity_range_type,
        min_=min_,
        max_=max_,
        fields=fields,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    type_: GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeType,
    player_id: int,
    time_entity_range_type: GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeTimeEntityRangeType,
    *,
    client: AuthenticatedClient,
    min_: datetime.datetime,
    max_: datetime.datetime,
    fields: Union[Unset, list[str]] = UNSET,
) -> Optional[list["PlayerStatistic"]]:
    """Request statistics for a range of statistics

    Args:
        type_ (GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeType):
        player_id (int):
        time_entity_range_type
            (GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeTimeEntityRangeType):
        min_ (datetime.datetime):
        max_ (datetime.datetime):
        fields (Union[Unset, list[str]]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['PlayerStatistic']
    """

    return sync_detailed(
        type_=type_,
        player_id=player_id,
        time_entity_range_type=time_entity_range_type,
        client=client,
        min_=min_,
        max_=max_,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    type_: GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeType,
    player_id: int,
    time_entity_range_type: GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeTimeEntityRangeType,
    *,
    client: AuthenticatedClient,
    min_: datetime.datetime,
    max_: datetime.datetime,
    fields: Union[Unset, list[str]] = UNSET,
) -> Response[list["PlayerStatistic"]]:
    """Request statistics for a range of statistics

    Args:
        type_ (GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeType):
        player_id (int):
        time_entity_range_type
            (GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeTimeEntityRangeType):
        min_ (datetime.datetime):
        max_ (datetime.datetime):
        fields (Union[Unset, list[str]]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['PlayerStatistic']]
    """

    kwargs = _get_kwargs(
        type_=type_,
        player_id=player_id,
        time_entity_range_type=time_entity_range_type,
        min_=min_,
        max_=max_,
        fields=fields,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    type_: GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeType,
    player_id: int,
    time_entity_range_type: GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeTimeEntityRangeType,
    *,
    client: AuthenticatedClient,
    min_: datetime.datetime,
    max_: datetime.datetime,
    fields: Union[Unset, list[str]] = UNSET,
) -> Optional[list["PlayerStatistic"]]:
    """Request statistics for a range of statistics

    Args:
        type_ (GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeType):
        player_id (int):
        time_entity_range_type
            (GetPublicV1StatisticsByTypeByPlayerIdByTimeEntityRangeTypeTimeEntityRangeType):
        min_ (datetime.datetime):
        max_ (datetime.datetime):
        fields (Union[Unset, list[str]]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['PlayerStatistic']
    """

    return (
        await asyncio_detailed(
            type_=type_,
            player_id=player_id,
            time_entity_range_type=time_entity_range_type,
            client=client,
            min_=min_,
            max_=max_,
            fields=fields,
        )
    ).parsed



from enum import Enum


class EventTypeIdentifier(str, Enum):
    ACCELERATION = "acceleration"
    BALL_CONTACT = "ball_contact"
    BALL_POSSESSION = "ball_possession"
    BALL_POSSESSION_LOST = "ball_possession_lost"
    BALL_POSSESSION_RECOVERY = "ball_possession_recovery"
    CHANGE_OF_DIRECTION = "change_of_direction"
    CHANGE_OF_ORIENTATION = "change_of_orientation"
    CHANGE_OF_PACE = "change_of_pace"
    CORNER_KICK = "corner_kick"
    COUNTER_ATTACK = "counter_attack"
    CUT = "cut"
    CV_SHOT = "cv_shot"
    DECELERATION = "deceleration"
    DEFENCE = "defence"
    DETECTED_CROSS = "detected_cross"
    DETECTED_OFFSIDE_SOCCER = "detected_offside_soccer"
    DETECTED_PASS = "detected_pass"
    DETECTED_SHOT_BASKETBALL = "detected_shot_basketball"
    DETECTED_SHOT_FIFA = "detected_shot_fifa"
    DETECTED_SHOT_HANDBALL = "detected_shot_handball"
    DETECTED_SHOT_ICE_HOCKEY = "detected_shot_ice_hockey"
    DETECTED_SHOT_INTELLIGENCE_COURT = "detected_shot_intelligence_court"
    DETECTED_SHOT_SOCCER = "detected_shot_soccer"
    DFL_CORNER_KICK = "dfl_corner_kick"
    DFL_CROSS = "dfl_cross"
    DFL_FREE_KICK = "dfl_free_kick"
    DFL_GOAL_KICK = "dfl_goal_kick"
    DFL_KICK_OFF = "dfl_kick_off"
    DFL_PASS = "dfl_pass"
    DFL_PENALTY = "dfl_penalty"
    DFL_SHOT_AT_GOAL = "dfl_shot_at_goal"
    DFL_SPRINT = "dfl_sprint"
    DFL_TACKLING = "dfl_tackling"
    DFL_THROW_IN = "dfl_throw_in"
    DOWN_ON_PADS = "down_on_pads"
    DRIBBLING_SOCCER = "dribbling_soccer"
    DYNAMIC_DEFENCE = "dynamic_defence"
    EXERTION = "exertion"
    FULL_COURT_TRANSITION = "full_court_transition"
    GOALKEEPER_SAVE_DIVING = "goalkeeper_save_diving"
    GOALKEEPER_SAVE_DOWN_TO_KNEES = "goalkeeper_save_down_to_knees"
    GOALKEEPER_SAVE_TILTING = "goalkeeper_save_tilting"
    GOAL_KICK = "goal_kick"
    GROUP_COUNTER_PRESSING = "group_counter_pressing"
    GROUP_EMPTY_GOAL_HANDBALL = "group_empty_goal_handball"
    HEART_RATE_RECOVERY = "heart_rate_recovery"
    IMPACT = "impact"
    JUMP = "jump"
    JUMP_BEACH_VOLLEYBALL = "jump_beach_volleyball"
    MID_COURT_TRANSITION = "mid_court_transition"
    NOAH_SHOT = "noah_shot"
    OFFENCE = "offence"
    PASS_FIFA = "pass_fifa"
    PICK_AND_POP = "pick_and_pop"
    PICK_AND_ROLL = "pick_and_roll"
    PIVOT_ROTATION = "pivot_rotation"
    PLAYER_COUNTER_PRESSING = "player_counter_pressing"
    PLAY_BY_PLAYER = "play_by_player"
    PLAY_BY_TEAM = "play_by_team"
    RALLY_BEACH_VOLLEYBALL = "rally_beach_volleyball"
    RSPCT_SHOT = "rspct_shot"
    SHIFT = "shift"
    SKATING_TRANSITION = "skating_transition"
    SPEED_ZONE_ENTRY = "speed_zone_entry"
    SPEED_ZONE_ENTRY_RELATIVE = "speed_zone_entry_relative"
    SPRINT = "sprint"
    TAG = "tag"
    TEMPO_RUN = "tempo_run"
    THROW_IN = "throw_in"
    TURN_ICE_HOCKEY = "turn_ice_hockey"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.event_cv_shot_shot_load_category import EventCvShotShotLoadCategory
from ..types import UNSET, Unset

T = TypeVar("T", bound="EventCvShot")


@_attrs_define
class EventCvShot:
    """
    Attributes:
        timestamp (Union[Unset, int]):
        timestamp_ms (Union[Unset, int]):
        timezone_id (Union[Unset, int]):
        game_clock (Union[Unset, str]):
        period (Union[Unset, str]):
        player_id (Union[Unset, int]):
        x (Union[Unset, float]):
        y (Union[Unset, float]):
        distance (Union[Unset, float]):
        made (Union[Unset, float]):
        shot_load (Union[Unset, float]):
        acceleration_max (Union[Unset, float]):
        deceleration_max (Union[Unset, float]):
        speed_max (Union[Unset, float]):
        jump_height (Union[Unset, float]):
        shot_load_category (Union[Unset, EventCvShotShotLoadCategory]):
    """

    timestamp: Union[Unset, int] = UNSET
    timestamp_ms: Union[Unset, int] = UNSET
    timezone_id: Union[Unset, int] = UNSET
    game_clock: Union[Unset, str] = UNSET
    period: Union[Unset, str] = UNSET
    player_id: Union[Unset, int] = UNSET
    x: Union[Unset, float] = UNSET
    y: Union[Unset, float] = UNSET
    distance: Union[Unset, float] = UNSET
    made: Union[Unset, float] = UNSET
    shot_load: Union[Unset, float] = UNSET
    acceleration_max: Union[Unset, float] = UNSET
    deceleration_max: Union[Unset, float] = UNSET
    speed_max: Union[Unset, float] = UNSET
    jump_height: Union[Unset, float] = UNSET
    shot_load_category: Union[Unset, EventCvShotShotLoadCategory] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        timestamp = self.timestamp

        timestamp_ms = self.timestamp_ms

        timezone_id = self.timezone_id

        game_clock = self.game_clock

        period = self.period

        player_id = self.player_id

        x = self.x

        y = self.y

        distance = self.distance

        made = self.made

        shot_load = self.shot_load

        acceleration_max = self.acceleration_max

        deceleration_max = self.deceleration_max

        speed_max = self.speed_max

        jump_height = self.jump_height

        shot_load_category: Union[Unset, str] = UNSET
        if not isinstance(self.shot_load_category, Unset):
            shot_load_category = self.shot_load_category.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if timestamp is not UNSET:
            field_dict["timestamp"] = timestamp
        if timestamp_ms is not UNSET:
            field_dict["timestamp_ms"] = timestamp_ms
        if timezone_id is not UNSET:
            field_dict["timezone_id"] = timezone_id
        if game_clock is not UNSET:
            field_dict["game_clock"] = game_clock
        if period is not UNSET:
            field_dict["period"] = period
        if player_id is not UNSET:
            field_dict["player_id"] = player_id
        if x is not UNSET:
            field_dict["x"] = x
        if y is not UNSET:
            field_dict["y"] = y
        if distance is not UNSET:
            field_dict["distance"] = distance
        if made is not UNSET:
            field_dict["made"] = made
        if shot_load is not UNSET:
            field_dict["shot_load"] = shot_load
        if acceleration_max is not UNSET:
            field_dict["acceleration_max"] = acceleration_max
        if deceleration_max is not UNSET:
            field_dict["deceleration_max"] = deceleration_max
        if speed_max is not UNSET:
            field_dict["speed_max"] = speed_max
        if jump_height is not UNSET:
            field_dict["jump_height"] = jump_height
        if shot_load_category is not UNSET:
            field_dict["shot_load_category"] = shot_load_category

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        timestamp = d.pop("timestamp", UNSET)

        timestamp_ms = d.pop("timestamp_ms", UNSET)

        timezone_id = d.pop("timezone_id", UNSET)

        game_clock = d.pop("game_clock", UNSET)

        period = d.pop("period", UNSET)

        player_id = d.pop("player_id", UNSET)

        x = d.pop("x", UNSET)

        y = d.pop("y", UNSET)

        distance = d.pop("distance", UNSET)

        made = d.pop("made", UNSET)

        shot_load = d.pop("shot_load", UNSET)

        acceleration_max = d.pop("acceleration_max", UNSET)

        deceleration_max = d.pop("deceleration_max", UNSET)

        speed_max = d.pop("speed_max", UNSET)

        jump_height = d.pop("jump_height", UNSET)

        _shot_load_category = d.pop("shot_load_category", UNSET)
        shot_load_category: Union[Unset, EventCvShotShotLoadCategory]
        if isinstance(_shot_load_category, Unset):
            shot_load_category = UNSET
        else:
            shot_load_category = EventCvShotShotLoadCategory(_shot_load_category)

        event_cv_shot = cls(
            timestamp=timestamp,
            timestamp_ms=timestamp_ms,
            timezone_id=timezone_id,
            game_clock=game_clock,
            period=period,
            player_id=player_id,
            x=x,
            y=y,
            distance=distance,
            made=made,
            shot_load=shot_load,
            acceleration_max=acceleration_max,
            deceleration_max=deceleration_max,
            speed_max=speed_max,
            jump_height=jump_height,
            shot_load_category=shot_load_category,
        )

        event_cv_shot.additional_properties = d
        return event_cv_shot

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class EventDflThrowInDflThrowInCategory(str, Enum):
    FAULT_EXECUTION = "fault_execution"
    MISSED = "missed"
    SUCCESSFUL = "successful"

    def __str__(self) -> str:
        return str(self.value)
